@@ -1,4 +1,6 @@
 import typer
+
+from pathlib import Path
 from scrapse.leggitalia.commands import scrap_judgments
 from scrapse.leggitalia.commands import dump_judgments
 from scrapse.leggitalia.commands import scrap_voices
@@ -24,6 +26,8 @@ def show_voices():
 @leggitalia_app.callback()
 def callback():
     """Dedicated command to the site LEGGI D'ITALIA PA"""
+    main_directory_path = Path('/'.join([str(Path.home()), 'scrapse', 'leggitalia']))
+    main_directory_path.mkdir(exist_ok=True, parents=True)
 
 
 if __name__ == "__main__":
